* Do-file "Common international trends in football stadium attendance"
* Panel data 30 clubs 63 seasons

clear

use "Attendance-Panel-Data.dta"
gen latt=log(average)
gen div1=(division=="Eerste Divisie")
gen div2=(division=="Tweede Divisie")
gen ere=1-div1-div2
gen points100=points/100
gen lhighest=log(highest)
gen lpl=log(pl)
gen lcinema=log(bios)
gen bios10=bios/10
gen larrest=log(arrest)
gen lcap=log(cap)
gen lpop=log(pop)
gen pos10=position/100
gen gd=(gf-ga)/100
gen lUrate=log(Urate)

encode team,gen(club)
encode season,gen(seizoen)
*xtset club seizoen
*iis year

*tabstat ere div1 div2,by(seizoen)
*tabstat ere div1 div2 if arrest~=.,by(seizoen)

gen ere63=ere*63
gen div163=div1*63
gen div263=div2*63

* Table 1 Summary Statistics
gen av1000=(average/1000)
gen highest1000=(highest/1000)
tabstat ere63 div163 div263 av1000 highest1000,by(club)
**********************
* Table 2a Data descriptives
sum av1000 highest1000 div1 div2 points100 pos10 gd
* Table 2b Data descriptives
sum Urate pl arrest bios10 if team=="Feyenoord"

* Figure 2a
sort year
*twoway line Urate year, ytitle("Unemployment rate (%)")  lpattern(solid) lcolor(black)|| line arrest year, lpattern(dash) lcolor(black) yaxis(2) ytitle("Arrests", axis(2)) ||, xtitle("Season/year") xlabel(1955(5)2020) graphregion(color(white)) bgcolor(white) legend(label(1 "Unemployment rate") label(2 "Arrests")  col(2))

* Figure 2b
*line bios10 year, ytitle("Cinema visits (mln)")  lpattern(solid) lcolor(black) xtitle("Year") xlabel(1955(5)2020) graphregion(color(white)) bgcolor(white) 

xtset club
* Table 3 column 1
xtreg latt i.year div1 div2 pos10 gd points100 lhighest, fe robust
*outreg2 using Simple, replace excel slow(1000) keep(div1 div2 pos10 gd points100 lhighest) label less(1)
* Table 3 column 2
xtreg latt i.year div1 div2 pos10 gd lhighest, fe robust
*outreg2 using Simple, append excel slow(1000) keep(div1 div2 pos10 gd points100 lhighest) label less(1)
* 
* Table 3 column 3
xtreg latt i.year div1 div2 pos10 gd points100 lhighest if larrest~=., fe robust
*outreg2 using Simple, append excel slow(1000) keep(div1 div2 pos10 gd points100 lhighest) label less(1)
* 
* Table 3 column 4
xtreg latt i.year div1 div2 pos10 gd lhighest if larrest~=., fe robust
*outreg2 using Simple, append excel slow(1000) keep(div1 div2 pos10 gd points100 lhighest) label less(1)

iis year
gen year10=year/10
* predictions for second stage - table 3 column 2
xtreg latt i.club div1 div2 pos10 gd lhighest, fe robust
predict yearhat,u
* Table 4 column 1
regress yearhat lUrate year10 if team=="Feyenoord",robust
* Table 4 column 2
regress yearhat lUrate year10 lpl if team=="Feyenoord",robust
* Table 4 column 3
regress yearhat lUrate year10 lpl lcinema if team=="Feyenoord",robust

* predictions for second stage - table 3 column 4
xtreg latt i.club div1 div2 pos10 gd lhighest if larrest~=., fe robust
predict yearhat2,u
* Table 4 column 1
regress yearhat2 lUrate year10 larrest if team=="Feyenoord",robust
* Table 4 column 2
regress yearhat2 lUrate year10 lpl larrest if team=="Feyenoord",robust
* Table 4 column 3
regress yearhat2 lUrate year10 lpl lcinema larrest if team=="Feyenoord",robust

***** THAT's IT ******* NOW some sensitivity analysis

************** ONE STEP Table 4 column 2 
xtset club
xtreg latt div1 div2 pos10 gd lhighest lUrate year10 lpl, fe robust

********* ONE STEP with clustering
xtreg latt div1 div2 pos10 gd lhighest lUrate year10 lpl, fe cluster(club)


**** ONE STEP analysis - no club variables
regress latt div1 div2 lUrate year10 lpl, robust
regress latt lUrate year10 lpl, robust
****** Replicate 
* Table 3 column 2 with lagged explanatory variables
sort club year
xtset club
gen lagpos10=pos10[_n-1]
gen laggd=gd[_n-1]
gen lagpoints100=points100[_n-1]
gen lagdiv1=div1[_n-1]
gen lagdiv2=div2[_n-1]

xtreg latt i.year div1 div2 lagdiv1 lagdiv2 lagpos10 laggd lhighest if year>1956, fe robust

*** without club fixed effects
regress latt i.year div1 div2 pos10 gd lhighest, robust




**** population rather than trend
regress yearhat lUrate lpop lpl lcinema if team=="Feyenoord",robust
regress yearhat2 lUrate lpop lpl lcinema larrest if team=="Feyenoord",robust

****** both population and trends
regress yearhat lUrate lpop year10 lpl lcinema if team=="Feyenoord",robust
regress yearhat2 lUrate lpop year10 lpl lcinema larrest if team=="Feyenoord",robust


*** quadratic trend
gen yearqua=year10*year10/10000
regress yearhat lUrate year10 yearqua lpl lcinema if team=="Feyenoord",robust

regress yearhat lUrate yearqua lpl lcinema if team=="Feyenoord",robust

* sum of goals
gen goalsum100=(gf+ga)/100
* Table 3 column 2
xtreg latt i.year div1 div2 pos10 goalsum100 lhighest, fe robust
xtreg latt i.year div1 div2 goalsum100 lhighest, fe robust
xtreg latt i.year div1 div2 pos10 gd goalsum100 lhighest, fe robust


* Ranking by division
gen pos10ere=pos10*(1-div1-div2)
gen pos10div1=pos10*div1
gen pos10div2=pos10*div2  

xtreg latt i.year div1 div2 pos10ere pos10div1 pos10div2 gd lhighest, fe robust
test pos10ere=pos10div1=pos10div2

* Point system
* 3-punten ingevoerd in 1995/96 (year=1995)
* Table 3 column 1
gen post1995=(year>1994)
gen pointsp1995=points100*post1995
xtreg latt i.year div1 div2 pos10 gd points100 pointsp1995 lhighest, fe robust
test pointsp1995=0


* clubspecific trends
gen clubt1=(club==1)*year/10
gen clubt2=(club==2)*year/10
gen clubt3=(club==3)*year/10
gen clubt4=(club==4)*year/10
gen clubt5=(club==5)*year/10
gen clubt6=(club==6)*year/10
gen clubt7=(club==7)*year/10
gen clubt8=(club==8)*year/10
gen clubt9=(club==9)*year/10
gen clubt10=(club==10)*year/10
gen clubt11=(club==11)*year/10
gen clubt12=(club==12)*year/10
gen clubt13=(club==13)*year/10
gen clubt14=(club==14)*year/10
gen clubt15=(club==15)*year/10
gen clubt16=(club==16)*year/10
gen clubt17=(club==17)*year/10
gen clubt18=(club==18)*year/10
gen clubt19=(club==19)*year/10
gen clubt20=(club==20)*year/10
gen clubt21=(club==21)*year/10
gen clubt22=(club==22)*year/10
gen clubt23=(club==23)*year/10
gen clubt24=(club==24)*year/10
gen clubt25=(club==25)*year/10
gen clubt26=(club==26)*year/10
gen clubt27=(club==27)*year/10
gen clubt28=(club==28)*year/10
gen clubt29=(club==29)*year/10
gen clubt30=(club==30)*year/10

xtreg latt clubt1 clubt2  clubt3 clubt4 clubt5 clubt6 clubt7 clubt8 clubt9 clubt10 clubt11 clubt12 clubt13 clubt14 clubt15 clubt16 clubt17 clubt18 clubt19 clubt20 clubt21 clubt22  clubt23 clubt24 clubt25 clubt26 clubt27 clubt28 clubt29 clubt30 i.year  div1 div2 pos10 gd lhighest, fe robust

***************************
******
* Exploratory analysis international data
*********************

clear 
use "Attendance-International-Data.dta"

* table below figure 1
pwcorr belgium england france germany netherlands italy, sig

gen lfr=ln(france)
gen len=ln(england)
gen lge=ln(germany)
gen lbe=ln(belgium)
gen lnl=ln(netherlands)
gen lit=ln(italy)

gen Int_Be4=ln((england+france+germany+netherlands)/4)
gen Int_En4=ln((belgium+france+germany+netherlands)/4)
gen Int_Fr4=ln((england+belgium+germany+netherlands)/4)
gen Int_Ge4=ln((england+france+belgium+netherlands)/4)
gen Int_Nl4=ln((england+france+germany+belgium)/4)
gen Int_It5=ln((england+france+germany+belgium+netherlands)/5)

gen lunl=ln(Urate)
gen luen=ln(uuk)
gen lufr=ln(ufr)
gen luge=ln(uge)
gen lube=ln(ub)
gen luit=ln(uit)
gen germuni=(year>1990)


keep if year>1962
gen year10=year/10

* Netherlands Table 5 column (1)
regress lnl lunl     year10,robust
regress lnl lunl len year10,robust
regress lnl lunl Int_Nl4 year10,robust

* England Table 5 column (2)
regress len luen     year10,robust
regress len luen Int_En4 year10,robust

* Germany Table 5 column (3)
regress lge luge     year10,robust
regress lge luge len year10,robust
regress lge luge Int_Ge4 year10,robust
regress lge      Int_Ge4 year10 germuni,robust

* France Table 5 column (4)
regress lfr lufr     year10,robust
regress lfr lufr len year10,robust
regress lfr lufr Int_Fr4 year10,robust

* Belgium Table 5 column (5)
regress lbe lube     year10,robust
regress lbe lube len year10,robust
regress lbe lube Int_Be4 year10,robust

* Italy 
*regress lit luitC     year,robust
*regress lit luitC IIT year,robust

* Figure 1
*twoway line england year,lcolor(black) lpattern(solid) || line germany year,lcolor(red) lpattern(dash) || line italy year,lcolor(blue) lpattern(longdash)ytitle("Attendance (1000)") title("") xtitle("Season (begin-year)") graphregion(color(white)) bgcolor(white)  xlabel(1955(10)2020) legend(col(3))

*twoway line belgium year,lcolor(black) lpattern(solid) || line france year,lcolor(red) lpattern(dash) || line netherlands year,lcolor(blue) lpattern(longdash)ytitle("Attendance (1000)") title("") xtitle("Season (begin-year)") graphregion(color(white)) bgcolor(white)  xlabel(1955(10)2020) legend(col(3))


*twoway line uuk year || line Urate year || line uge year || line ub year || line ufr year


* Figure 3
* predictions
regress lnl lunl Int_Nl4 year10,robust
predict lnlpr
gen nlpr=exp(lnlpr)
twoway line netherlands year,lcolor(black) lpattern(solid) || line nlpr year,lcolor(blue) lpattern(dash) ytitle("Attendance (1000)") title("") xtitle("Season (begin-year)") graphregion(color(white)) bgcolor(white)  xlabel(1960(10)2020) legend(label(1 "Netherlands") label(2 "Predicted"))

regress len luen Int_En4 year10,robust
predict lenpr
gen enpr=exp(lenpr)
twoway line england year,lcolor(black) lpattern(solid) || line  enpr year,lcolor(blue) lpattern(dash)   ytitle("Attendance (1000)") title("") xtitle("Season (begin-year)") graphregion(color(white)) bgcolor(white)  xlabel(1960(10)2020) legend(label(1 "England") label(2 "Predicted"))

regress lbe lube Int_Be4 year10 ,robust
predict lbepr
gen bepr=exp(lbepr)
twoway line belgium year,lcolor(black) lpattern(solid) || line  bepr year,lcolor(blue) lpattern(dash)   ytitle("Attendance (1000)") title("") xtitle("Season (begin-year)") graphregion(color(white)) bgcolor(white)  xlabel(1960(10)2020) legend(label(1 "Belgium") label(2 "Predicted"))

regress lge luge Int_Ge4 year10 ,robust
predict lgepr
gen gepr=exp(lgepr)
twoway line germany year,lcolor(black) lpattern(solid) || line  gepr year,lcolor(blue) lpattern(dash)   ytitle("Attendance (1000)") title("") xtitle("Season (begin-year)") graphregion(color(white)) bgcolor(white)  xlabel(1960(10)2020) legend(label(1 "Germany") label(2 "Predicted"))

regress lfr Int_Fr4 year10,robust
predict lfrpr
gen frpr=exp(lfrpr)
twoway line france year,lcolor(black) lpattern(solid) || line  frpr year,lcolor(blue) lpattern(dash)   ytitle("Attendance (1000)") title("") xtitle("Season (begin-year)") graphregion(color(white)) bgcolor(white)  xlabel(1960(10)2020) legend(label(1 "France") label(2 "Predicted"))




